from distutils.core import setup

setup(
         name = "name_cgf",
         version = "1.0.0",
         py_modules = ["name_cgf"],
         author = "cgf",
         author_email = "247858638@qq.com",
         url = "http://www/headfirstlabs.com",
         description = "heheda",
     )


